using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace hammer
{
    public partial class GotoForm : Form
    {
        private int maxLines;

        public static bool Execute(IntSight.Controls.CodeEditor editor)
        {
            using (GotoForm form = new GotoForm())
            {
                form.maxLines = editor.LineCount;
                form.label.Text = String.Format(form.label.Text, form.maxLines);
                form.textBox.Text = editor.CurrentLine.ToString();
                if (form.ShowDialog(editor.FindForm()) == DialogResult.OK)
                {
                    editor.CurrentLine = Int32.Parse(form.textBox.Text);
                    return true;
                }
                return false;
            }
        }

        private GotoForm()
        {
            InitializeComponent();
            Opacity = (MainForm.GlobalOpacity - 1) / 100.0;
        }

        private void ShowError(string message)
        {
            toolTip.Show(message, textBox, textBox.Width, textBox.Height, 3000);
        }

        private void GotoForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (this.DialogResult == DialogResult.OK)
            {
                int value;
                if (!int.TryParse(textBox.Text, out value))
                {
                    ShowError("Line number is not an integer value.");
                    e.Cancel = true;
                }
                else if (value < 1)
                {
                    ShowError("Line number can't be lesser than 1.");
                    e.Cancel = true;
                }
                else if (value > maxLines)
                {
                    ShowError(String.Format(
                        "Line number can't be greater than {0}.", maxLines));
                    e.Cancel = true;
                }
                if (e.Cancel)
                    textBox.Focus();
            }
        }

        private void textBox_Click(object sender, EventArgs e)
        {
            toolTip.Hide(textBox);
        }

        private void textBox_KeyPress(object sender, KeyPressEventArgs e)
        {
            toolTip.Hide(textBox);
            if (e.KeyChar >= 32)
                if (e.KeyChar < '0' || e.KeyChar > '9')
                {
                    ShowError("Enter a valid line number, please.");
                    e.Handled = true;
                }
        }

        private void GotoForm_FormClosed(object sender, FormClosedEventArgs e)
        {
            toolTip.Hide(textBox);
        }
    }
}