using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Windows.Forms;
using IntSight.Controls;
using IntSight.Controls.CodeModel;

namespace hammer
{
    internal class FileSnippet : ICodeSnippet
    {
        private string name, description, text;

        public FileSnippet(string path)
        {
            using (TextReader reader = File.OpenText(path))
            {
                name = reader.ReadLine();
                description = reader.ReadLine();
                text = reader.ReadToEnd();
                if (name == null) name = String.Empty;
                if (description == null) description = String.Empty;
                if (text == null) text = String.Empty;
            }
        }

        #region ICodeSnippet Members

        public string Description { get { return description; } }
        public string Name { get { return name; } }
        public string Text { get { return text; } }

        #endregion
    }

    internal class SnippetManager : ISnippetManager
    {
        private List<ICodeSnippet> snippets;

        public SnippetManager(string directory)
        {
            snippets = new List<ICodeSnippet>();
            foreach (string fileName in Directory.GetFiles(
                directory, "*.code", SearchOption.TopDirectoryOnly))
                snippets.Add(new FileSnippet(fileName));
        }

        #region ISnippetManager Members

        public ICodeSnippet[] GetSnippets(string partialName)
        {
            partialName = partialName.ToLowerInvariant();
            List<ICodeSnippet> result = new List<ICodeSnippet>();
            foreach (ICodeSnippet snippet in snippets)
                if (snippet.Name.ToLowerInvariant().StartsWith(partialName))
                    result.Add(snippet);
            return result.ToArray();
        }

        public void Refresh()
        {
        }

        public void Select(ICodeSnippet[] snippets, Control editor, int x, int y, bool isSurround, ICodeSnippetCallback callback)
        {
            SnippetBox.Select(snippets, editor, x, y, callback);
        }

        #endregion
    }
}